# InlineResponse200

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** | The type of API result, e.g., &#x60;search&#x60;. | [optional] 
**query** | [**InlineResponse200Query**](InlineResponse200Query.md) |  | [optional] 
**web** | [**InlineResponse200Web**](InlineResponse200Web.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

